Welcome!
========

Xtesting have leveraged on Functest efforts to provide a reference testing
framework:

  * Requirements Management: https://wiki.opnfv.org/display/functest/Requirements+management
  * Docker Slicing: http://testresults.opnfv.org/functest/dockerslicing/
  * Functest Framework: http://testresults.opnfv.org/functest/framework/

Xtesting aims at allowing a smooth integration of new Functest Kubernetes
testcases.

But, more generally, it eases building any CI/CD toolchain for other
domains than testing Virtualized Infrastructure Managers (VIM) such as
`OpenStack <https://www.openstack.org/>`_.

To learn more about Xtesting:

  * Documentation: http://xtesting.readthedocs.io/en/latest/
  * Gerrit: https://gerrit.opnfv.org/gerrit/#/q/project:functest-xtesting

Get in touch via `email <mailto:opnfv-tech-discuss@lists.opnfv.org>`_.
